@@ -486,6 +486,9 @@ class NormalFormGame:
     nums_actions : tuple(int)
         Tuple of the numbers of actions, one for each player.
 
+    payoff_arrays : tuple(ndarray(float, ndim=N))
+        Tuple of the payoff arrays, one for each player.
+
     """
     def __init__(self, data, dtype=None):
         # data represents an array_like of Players
@@ -575,6 +578,9 @@ class NormalFormGame:
         self.nums_actions = tuple(
             player.num_actions for player in self.players
         )
+        self.payoff_arrays = tuple(
+            player.payoff_array for player in self.players
+        )
 
     @property
     def payoff_profile_array(self):
