@@ -9,13 +9,16 @@ Methods for computing pure Nash equilibria of a normal form game.
 import numpy as np
 
 
-def pure_nash_brute(g):
+def pure_nash_brute(g, tol=None):
     """
     Find all pure Nash equilibria of a normal form game by brute force.
 
     Parameters
     ----------
     g : NormalFormGame
+    tol : scalar(float), optional(default=None)
+        Tolerance level used in determining best responses. If None,
+        default to the value of the `tol` attribute of `g`.
 
     Returns
     -------
@@ -43,16 +46,19 @@ def pure_nash_brute(g):
     []
 
     """
-    return list(pure_nash_brute_gen(g))
+    return list(pure_nash_brute_gen(g, tol=tol))
 
 
-def pure_nash_brute_gen(g):
+def pure_nash_brute_gen(g, tol=None):
     """
     Generator version of `pure_nash_brute`.
 
     Parameters
     ----------
     g : NormalFormGame
+    tol : scalar(float), optional(default=None)
+        Tolerance level used in determining best responses. If None,
+        default to the value of the `tol` attribute of `g`.
 
     Yields
     ------
@@ -61,5 +67,5 @@ def pure_nash_brute_gen(g):
 
     """
     for a in np.ndindex(*g.nums_actions):
-        if g.is_nash(a):
+        if g.is_nash(a, tol=tol):
             yield a
